pyxmpp.roster

Package pyxmpp :: Module roster |
[hide private]

# Module roster

source code

XMPP-IM roster handling.

Normative reference:
  - RFC 3921

Classes | [hide private]
| RosterItem Roster item.
| Roster Class representing XMPP-IM roster.

Variables | [hide private]
| __revision__ = ``'``$Id: roster.py 714 2010-04-05 10:20:10Z jajcus $``'``
| ROSTER_NS = ``'``jabber:iq:roster``'``
| __package__ = ``'``pyxmpp``'``

Imports: libxml2, common_doc, get_node_ns_uri, Iq, JID, to_utf8, from_utf8, StanzaPayloadObject